# System
import os
import json


class JsonCache:
    """
    Store key value pairs in a JSON file
    """

    def __init__(self, cache_path):
        self.cache_path = cache_path

    def get_cache(self):
        """
        Get the dictionary from the cache file
        or if it doesn't exist, return an empty dictionary
        """

        if os.path.isfile(self.cache_path):
            with open(self.cache_path) as cache_file:
                return json.load(cache_file)
        else:
            return {}

    def put_cache(self, cache):
        """
        Save a dictionary to the JSON cache file
        """

        with open(self.cache_path, 'w') as cache_file:
            json.dump(cache, cache_file)

    def set(self, name, value):
        """
        Set a key value pair to the cache
        """

        cache = self.get_cache()
        cache[name] = value
        self.put_cache(cache)

    def get(self, name):
        """
        Retrieve a value from the cache by key
        """

        return self.get_cache().get(name)

    def wipe(self):
        """
        Remove the cache file
        """

        if os.path.isfile(self.cache_path):
            os.remove(self.cache_path)
